@@ -20,6 +20,11 @@
 
 #include "alsa_classes.h"
 
+//i18n stuff
+#include "gettext.h"
+#include <locale.h>
+#define _(String) gettext (String)
+
 
 //Constructor: automatically populates the element with its non-dynamic data
 Element::Element(char *_card, int _numid, const char *_name){
@@ -28,6 +33,8 @@ Element::Element(char *_card, int _numid, const char *_name){
 	numid = _numid;
 	strcpy(name, _name);
 	switch_id = -1; //this will be changed later if there is an associated switch
+	scaling = LINEAR; //this will be set later
+	auto_mute = true; //this can be set later
 	associated = false; //this one is also handled later
 	
 	//set the short name by dropping any trailing "Playback*", "Volume*", or "Switch*"
@@ -75,7 +82,7 @@ Element::Element(char *_card, int _numid, const char *_name){
 	
 	//open a handle to use with the card
 	if ((err = snd_ctl_open(&handle, card, 0)) < 0) {
-		fprintf(stderr, "Control %s open error: %s\n", card, snd_strerror(err));
+		fprintf(stderr, _("Control %s open error: %s\n"), card, snd_strerror(err));
 	}
 	
 	snd_ctl_elem_read(handle, control);
@@ -158,13 +165,35 @@ void Element::print(){
 //this is used internally to scale a number to be from 0-100
 int Element::scale_out(int num){
 	if(max-min==0){ return(num); }
-	return(ceil(100.0*(num-min)/(max-min)));
+	switch (scaling){
+		case LOGARITHMIC:
+			return(round(pow(101.0, (num-min)/(double)(max-min)))-1);
+			break;
+		case EXPONENTIAL:
+			return(round(log(100*(num-min)/(double)(max-min)+1)/log(101)*100));
+			break;
+		case LINEAR:
+		default:
+			return(ceil(100.0*(num-min)/(max-min)));
+			break;
+	}
 }
 //this is the inverse of scale_out; it's used to take a 0-100 number and put it
 //into the proper scale for the element to understand
 int Element::scale_in(int num){
 	if(max-min==0){ return(num); }
-	return(floor((num*(max-min)/(100))+min));
+	switch (scaling){
+		case LOGARITHMIC:
+			return(round((log(num+1)/log(101)*(max-min))+min));
+			break;
+		case EXPONENTIAL:
+			return(round((pow((101.0), num/(double)100)-1)*(max-min)/100.0+min));
+			break;
+		case LINEAR:
+		default:
+			return(floor((num*(max-min)/(100))+min));
+			break;
+	}
 }
 //this will grab the highest value in the element
 int Element::get(){
@@ -236,7 +265,8 @@ int Element::_get(int n){
 	
 	//open a handle to use with the card
 	if ((err = snd_ctl_open(&handle, card, 0)) < 0) {
-		fprintf(stderr, "Control %s open error: %s\n", card, snd_strerror(err));
+		fprintf(stderr, _("Control %s open error: %s\n"), card, snd_strerror(err));
+		return 0;
 	}
 	
 	snd_ctl_elem_read(handle, control);
@@ -285,7 +315,7 @@ void Element::sget(char *ret){
 	
 	//open a handle to use with the card
 	if ((err = snd_ctl_open(&handle, card, 0)) < 0) {
-		fprintf(stderr, "Control %s open error: %s\n", card, snd_strerror(err));
+		fprintf(stderr, _("Control %s open error: %s\n"), card, snd_strerror(err));
 	}
 	
 	snd_ctl_elem_read(handle, control);
@@ -329,7 +359,8 @@ int Element::_set(int num, int n){
 	
 	//open a handle to use with the card
 	if ((err = snd_ctl_open(&handle, card, 0)) < 0) {
-		fprintf(stderr, "Control %s open error: %s\n", card, snd_strerror(err));
+		fprintf(stderr, _("Control %s open error: %s\n"), card, snd_strerror(err));
+		return 0;
 	}
 	
 	
@@ -369,6 +400,16 @@ int Element::_set(int num, int n){
 	
 	//don't need the handle open anymore, so close it
 	snd_ctl_close(handle);
+
+
+	//now, if auto_mute is set and this has a switch, handle that
+	if (auto_mute && strcmp(type, "INTEGER") == 0 && switch_ptr){
+		if (num == 0){
+			switch_ptr->set(0);
+		} else {
+			switch_ptr->set(1);
+		}
+	}
 	
 	return(num);
 	
@@ -386,11 +427,24 @@ int Element::_set(int num, int n){
 ElementList::ElementList(char *_card){
 	strcpy(card, _card);
 	
+	num_elems = 0;
+	elems = NULL;
+	num_items = 0;
+	items = NULL;
 	
 	//open a pointer to use
+	int err = 0;
 	snd_hctl_t *hctl;
-	snd_hctl_open(&hctl, card, SND_CTL_NONBLOCK | SND_CTL_ASYNC);
-	snd_hctl_load(hctl);
+	err = snd_hctl_open(&hctl, card, SND_CTL_NONBLOCK | SND_CTL_ASYNC);
+	if (err){
+		fprintf(stderr, _("Unable to open card %s: %s\n"), card, snd_strerror(err));
+		return;
+	}
+	err = snd_hctl_load(hctl);
+	if (err){
+		fprintf(stderr, _("Unable to load control for card %s: %s\n"), card, snd_strerror(err));
+		return;
+	}
 	
 	//get the total number and allocate the array
 	num_elems = snd_hctl_get_count(hctl);
@@ -424,6 +478,7 @@ ElementList::ElementList(char *_card){
 			for (int j=0; j<num_elems; j++){
 				if (strstr(elems[j].name, buffer) && !strstr(elems[j].name, "Switch") && elems[j].index == elems[i].index){
 					elems[j].switch_id = i;
+					elems[j].switch_ptr = &(elems[i]);
 					elems[j].associated = elems[i].associated = true;
 				}
 			}
@@ -589,6 +644,22 @@ void ElementList::reorder_items(int *order, int n){
 }
 
 
+//updates the scale for all elements
+void ElementList::set_scale(Element::scale_t s){
+	for (int i=0; i<num_elems; i++){
+		elems[i].scaling = s;
+	}
+}
+
+
+//updates the auto_mute for all elements
+void ElementList::set_auto_mute(bool a){
+	for (int i=0; i<num_elems; i++){
+		elems[i].auto_mute = a;
+	}
+}
+
+
 //replaces any instance of 'oldstr' found in dest with newstr, and returns true if dest was modified
 bool strrep(char *dest, char *oldstr, char *newstr){
 	if (char *start = strstr(dest, oldstr)){
