@@ -23,6 +23,8 @@ ConfigSettings::ConfigSettings(){
 	num_numids = 0;
 	//defaults
 	strcpy(_d_card, "hw:0");
+	_d_scaling = Element::LINEAR;
+	_d_auto_mute = true;
 	_d_vertical = false;
 	_d_window_x=-1;
 	_d_window_y=-1;
@@ -63,9 +65,16 @@ ConfigSettings::ConfigSettings(){
 	
 	
 	strcpy(icon_file_names[0], VOL_MUTED_IMAGE);
-	strcpy(icon_file_names[1], VOL_LOW_IMAGE);
-	strcpy(icon_file_names[2], VOL_MEDIUM_IMAGE);
-	strcpy(icon_file_names[3], VOL_HIGH_IMAGE);
+	strcpy(icon_file_names[1], VOL_NONE_IMAGE);
+	strcpy(icon_file_names[2], VOL_LOW_IMAGE);
+	strcpy(icon_file_names[3], VOL_MEDIUM_IMAGE);
+	strcpy(icon_file_names[4], VOL_HIGH_IMAGE);
+
+	tray_icon = NULL;
+	tray_icon_image = NULL;
+	tray_icon_menu = NULL;
+	tray_slider = NULL;
+	tray_control = NULL;
 
 	apply_defaults();
 }
@@ -75,6 +84,8 @@ void ConfigSettings::apply_defaults(){
 	restart = false;
 	resume_main = false;
 	strcpy(card, _d_card);
+	scaling = _d_scaling;
+	auto_mute = _d_auto_mute;
 	vertical = _d_vertical;
 	window_x = _d_window_x;
 	window_y = _d_window_y;
@@ -157,6 +168,8 @@ void ConfigSettings::copy_settings(ConfigSettings *ptr){
 	strcpy(card, ptr->card);
 	list_ptr = ptr->list_ptr;
 	num_numids = ptr->num_numids;
+	scaling = ptr->scaling;
+	auto_mute = ptr->auto_mute;
 	vertical = ptr->vertical;
 	window_x = ptr->window_x;
 	window_y = ptr->window_y;
@@ -215,6 +228,13 @@ void ConfigSettings::parse_config(char *config_file){
 		if (strcmp(tmpptr, "card")==0){
 			tmpptr=strtok(NULL, "=\"\n");
 			strcpy(card, tmpptr);
+		} else if (strcmp(tmpptr, "scaling")==0){
+			tmpptr=strtok(NULL, "=\n");
+			scaling=atoi(tmpptr);
+			if (scaling < 0 || scaling > NUM_SCALE_T - 1){ scaling = _d_scaling; }  //if out of bounds, use default
+		} else if (strcmp(tmpptr, "auto_mute")==0){
+			tmpptr=strtok(NULL, "=\n");
+			auto_mute=(bool)atoi(tmpptr);
 		} else if (strcmp(tmpptr, "vertical")==0){
 			tmpptr=strtok(NULL, "=\n");
 			vertical=(bool)atoi(tmpptr);
@@ -325,6 +345,13 @@ void ConfigSettings::write_config(){
 	fprintf(cfile, "#card=%s\n", _d_card);
 	if (strcmp(card, _d_card) != 0){ fprintf(cfile, "card=%s\n", card); }
 
+	fputs(_("\n# Set this to 0-2 to define a linear, logarithmic, or exponential volume scale, respectively\n"), cfile);
+	fprintf(cfile, "#scaling=%d\n", _d_scaling);
+	if (scaling != _d_scaling){ fprintf(cfile, "scaling=%d\n", scaling); }
+	fputs(_("\n# Set this to 1 to make the volume automatically mute when set to 0%, or 0 to keep it unmuted at 0%\n"), cfile);
+	fprintf(cfile, "#auto_mute=%d\n", _d_auto_mute);
+	if (auto_mute != _d_auto_mute){ fprintf(cfile, "auto_mute=%d\n", auto_mute); }
+
 	fputs(_("\n# Set this to 1 to make the sliders vertical, or 0 for horizontal (only applies to the main window)\n"), cfile);
 	fprintf(cfile, "#vertical=%d\n", _d_vertical);
 	if (vertical != _d_vertical){ fprintf(cfile, "vertical=%d\n", vertical); }
@@ -423,7 +450,7 @@ void ConfigSettings::write_config(){
 void ConfigSettings::reorder_list(ElementList *list){
 	list_ptr = list;
 	//this function is not needed unless an order has been defined somewhere
-	if (num_numids!=0){
+	if (num_numids!=0 && list && list->num_elems > 0){
 		
 		int *order = new int[list_ptr->num_items];
 
@@ -477,7 +504,7 @@ void ConfigSettings::set_tray_slider(ElementList *list){
 		attempt++;
 	}
 	//still nothing, so just take the first element
-	if(tray_control_numid<0 || !tray_control){
+	if((tray_control_numid<0 || !tray_control) && list->num_elems>0){
 		tray_control = &(list->elems[0]);
 		tray_control_numid = list->elems[0].numid;
 	}
