@@ -76,76 +76,78 @@ gboolean tray_button_press_event_callback (GObject *widget, GdkEventButton *even
 	
 	switch(event->button){
 		case 1:		//left mouse button - toggle slider_window
-			if (GTK_WIDGET_VISIBLE(slider_window)){
-				gtk_widget_hide_all(slider_window);
-			} else {
-				int slider_width, slider_height, icon_width, icon_height, x_pos, y_pos;
-				int tray_offset; //this may be needed if the tray border hides the bottom of the slider
-				//get some dimensions
-				gtk_window_get_size(GTK_WINDOW(slider_window), &slider_width, &slider_height);
-				GdkScreen *screen = gdk_screen_get_default();
+			if (settings.tray_control){
+				if (GTK_WIDGET_VISIBLE(slider_window)){
+					gtk_widget_hide_all(slider_window);
+				} else {
+					int slider_width, slider_height, icon_width, icon_height, x_pos, y_pos;
+					int tray_offset; //this may be needed if the tray border hides the bottom of the slider
+					//get some dimensions
+					gtk_window_get_size(GTK_WINDOW(slider_window), &slider_width, &slider_height);
+					GdkScreen *screen = gdk_screen_get_default();
 #if GTK_CHECK_VERSION(2,16,0)
-				GdkScreen *screen_from_tray;
-				GdkRectangle area;
-				GtkOrientation orientation;
-				if (gtk_status_icon_get_geometry(settings.tray_icon, &screen_from_tray, &area, &orientation)){
-					icon_width = area.width;
-					icon_height = area.height;
-				} else {
-					//just outright guess
-					icon_width = 24;
-					icon_height = 24;
-				}
+					GdkScreen *screen_from_tray;
+					GdkRectangle area;
+					GtkOrientation orientation;
+					if (gtk_status_icon_get_geometry(settings.tray_icon, &screen_from_tray, &area, &orientation)){
+						icon_width = area.width;
+						icon_height = area.height;
+					} else {
+						//just outright guess
+						icon_width = 24;
+						icon_height = 24;
+					}
 #else
-				gtk_window_get_size(GTK_WINDOW(widget), &icon_width, &icon_height);
+					gtk_window_get_size(GTK_WINDOW(widget), &icon_width, &icon_height);
 #endif
-				//compute the x position
-				//x_pos = event->x_root - event->x - slider_width/2 + widget->allocation.width/2;
-				x_pos = event->x_root - event->x - slider_width/2 + icon_width/2;
-				//if the user has supplied an offset, use that, otherwise guess
-				if (settings.tray_slider_offset >= 0){
-					tray_offset = settings.tray_slider_offset;
-				} else {
+					//compute the x position
+					//x_pos = event->x_root - event->x - slider_width/2 + widget->allocation.width/2;
+					x_pos = event->x_root - event->x - slider_width/2 + icon_width/2;
+					//if the user has supplied an offset, use that, otherwise guess
+					if (settings.tray_slider_offset >= 0){
+						tray_offset = settings.tray_slider_offset;
+					} else {
+						if (event->y_root > gdk_screen_get_height(screen)/2){
+							//tray at bottom
+							tray_offset = gdk_screen_get_height(screen) - icon_height - event->y_root + event->y;
+						} else {
+							//tray at top
+							tray_offset = event->y_root - event->y;
+						}
+					}
+					//compute the y position
 					if (event->y_root > gdk_screen_get_height(screen)/2){
 						//tray at bottom
-						tray_offset = gdk_screen_get_height(screen) - icon_height - event->y_root + event->y;
+						y_pos = event->y_root-event->y-slider_height-tray_offset;
 					} else {
 						//tray at top
-						tray_offset = event->y_root - event->y;
+						y_pos = icon_height+event->y_root-event->y+tray_offset;
+					}
+					//do the deed
+					gtk_window_move(GTK_WINDOW(slider_window), x_pos, y_pos);
+					gtk_widget_show_all(slider_window);
+				}
+				break;
+			case 3:		//right mouse button - display tray menu or main window, depending on settings.enable_tray_menu
+				if (settings.enable_tray_menu){
+					gtk_menu_popup(GTK_MENU(settings.tray_icon_menu), NULL, NULL, NULL, NULL, event->button, event->time);
+				} else {
+					if (GTK_WIDGET_VISIBLE(settings.main_window)){
+						gtk_widget_hide(settings.main_window);
+					} else {
+						gtk_widget_show_all(settings.main_window);
 					}
 				}
-				//compute the y position
-				if (event->y_root > gdk_screen_get_height(screen)/2){
-					//tray at bottom
-					y_pos = event->y_root-event->y-slider_height-tray_offset;
-				} else {
-					//tray at top
-					y_pos = icon_height+event->y_root-event->y+tray_offset;
+				break;
+			case 2:		//middle mouse button - mute
+				if (settings.tray_control && settings.tray_control->switch_id >= 0){
+					bool state = !(bool)list_ptr->elems[settings.tray_control->switch_id].get();
+					list_ptr->elems[settings.tray_control->switch_id].set((int)(state));
 				}
-				//do the deed
-				gtk_window_move(GTK_WINDOW(slider_window), x_pos, y_pos);
-				gtk_widget_show_all(slider_window);
-			}
-			break;
-		case 3:		//right mouse button - display tray menu or main window, depending on settings.enable_tray_menu
-			if (settings.enable_tray_menu){
-				gtk_menu_popup(GTK_MENU(settings.tray_icon_menu), NULL, NULL, NULL, NULL, event->button, event->time);
-			} else {
-				if (GTK_WIDGET_VISIBLE(settings.main_window)){
-					gtk_widget_hide(settings.main_window);
-				} else {
-					gtk_widget_show_all(settings.main_window);
-				}
-			}
-			break;
-		case 2:		//middle mouse button - mute
-			if (settings.tray_control->switch_id >= 0){
-				bool state = !(bool)list_ptr->elems[settings.tray_control->switch_id].get();
-				list_ptr->elems[settings.tray_control->switch_id].set((int)(state));
-			}
-			break;
-		default:
-			break;
+				break;
+			default:
+				break;
+		}
 	}
 	
 	update(NULL);
@@ -156,67 +158,74 @@ gboolean tray_button_press_event_callback (GObject *widget, GdkEventButton *even
 gboolean update(gpointer data){
 	bool state = true;
 	if (settings.enable_tray_icon){
-		int val = settings.tray_control->get();
-		char tooltiptext[32];
-		if (settings.tray_control->switch_id >= 0){
-			state = (bool)list_ptr->elems[settings.tray_control->switch_id].get();
-		}
-		if (state && val != 0){
-			int image = 1+3*val/100;
-			if (image > 3){
-				image=3;
-			} else if (image < 0){
-				image=0;
+		if (settings.tray_control){
+			int val = settings.tray_control->get();
+			char tooltiptext[32];
+			if (settings.tray_control->switch_id >= 0){
+				state = (bool)list_ptr->elems[settings.tray_control->switch_id].get();
 			}
-			sprintf(tooltiptext, _("Volume: %d%%"), val);
+			if (state){
+				int image = 2+3*val/100;
+				if (image > 4){
+					image=4;
+				} else if (image < 0){
+					image=0;
+				} else if (val == 0){
+					image=1;
+				}
+				sprintf(tooltiptext, _("Volume: %d%%"), val);
 #if GTK_CHECK_VERSION(2,16,0)
-			gtk_status_icon_set_from_file(settings.tray_icon, settings.icon_file_names[image]);
+				gtk_status_icon_set_from_file(settings.tray_icon, settings.icon_file_names[image]);
 #else
-			gtk_image_set_from_file(GTK_IMAGE(settings.tray_icon_image), settings.icon_file_names[image]);
+				gtk_image_set_from_file(GTK_IMAGE(settings.tray_icon_image), settings.icon_file_names[image]);
 #endif
-		} else {
-			sprintf(tooltiptext, _("Volume: Muted"));
+			} else {
+				sprintf(tooltiptext, _("Volume: Muted"));
 #if GTK_CHECK_VERSION(2,16,0)
-			gtk_status_icon_set_from_file(settings.tray_icon, settings.icon_file_names[0]);
+				gtk_status_icon_set_from_file(settings.tray_icon, settings.icon_file_names[0]);
 #else
-			gtk_image_set_from_file(GTK_IMAGE(settings.tray_icon_image), settings.icon_file_names[0]);
+				gtk_image_set_from_file(GTK_IMAGE(settings.tray_icon_image), settings.icon_file_names[0]);
 #endif
-		}
+			}
 #if GTK_CHECK_VERSION(2,16,0)
-			gtk_status_icon_set_tooltip_text(settings.tray_icon, tooltiptext);
+				gtk_status_icon_set_tooltip_text(settings.tray_icon, tooltiptext);
 #elif GTK_CHECK_VERSION(2,12,0)
-			gtk_widget_set_tooltip_text(settings.tray_icon_image, tooltiptext);
+				gtk_widget_set_tooltip_text(settings.tray_icon_image, tooltiptext);
 #else
-			static GtkTooltips *tooltips = gtk_tooltips_new();
-			gtk_tooltips_set_tip(tooltips, settings.tray_icon_image, tooltiptext, NULL);
+				static GtkTooltips *tooltips = gtk_tooltips_new();
+				gtk_tooltips_set_tip(tooltips, settings.tray_icon_image, tooltiptext, NULL);
 #endif
-		//if the tray was moved, update the menu
-		GdkScreen *screen = gdk_screen_get_default();
-		int icon_x,icon_y;
+			//if the tray was moved, update the menu
+			GdkScreen *screen = gdk_screen_get_default();
+			int icon_x,icon_y;
 #if GTK_CHECK_VERSION(2,16,0)
-		GdkScreen *screen_from_tray;
-		GdkRectangle area;
-		GtkOrientation orientation;
-		if (gtk_status_icon_get_geometry(settings.tray_icon, &screen_from_tray, &area, &orientation)){
-			icon_x = area.x;
-			icon_y = area.y;
-		} else {
-			icon_x = gdk_screen_get_width(screen);
-			icon_y = gdk_screen_get_height(screen);
-		}
+			GdkScreen *screen_from_tray;
+			GdkRectangle area;
+			GtkOrientation orientation;
+			if (gtk_status_icon_get_geometry(settings.tray_icon, &screen_from_tray, &area, &orientation)){
+				icon_x = area.x;
+				icon_y = area.y;
+			} else {
+				icon_x = gdk_screen_get_width(screen);
+				icon_y = gdk_screen_get_height(screen);
+			}
 #else
-		gtk_window_get_position(GTK_WINDOW(settings.tray_icon), &icon_x, &icon_y);
+			gtk_window_get_position(GTK_WINDOW(settings.tray_icon), &icon_x, &icon_y);
 #endif
-		if ((bool)(icon_y > gdk_screen_get_height(screen)/2) ^ tray_at_bottom){
-			//the current status does not match the previous status, so update the menu
-			set_menu();
-		}
-		//in case the icon was hidden due to the tray exiting, try reshowing it again
+			if ((bool)(icon_y > gdk_screen_get_height(screen)/2) ^ tray_at_bottom){
+				//the current status does not match the previous status, so update the menu
+				set_menu();
+			}
+			//in case the icon was hidden due to the tray exiting, try reshowing it again
 #if GTK_CHECK_VERSION(2,16,0)
-		gtk_status_icon_set_visible(settings.tray_icon, true);
+			gtk_status_icon_set_visible(settings.tray_icon, true);
 #else
-		gtk_widget_show_all(settings.tray_icon);
+			gtk_widget_show_all(settings.tray_icon);
 #endif
+		}
+		if (GTK_WIDGET_VISIBLE(settings.slider_window)){
+			gtk_widget_queue_draw(settings.slider_window);
+		}
 	}
 	if (GTK_WIDGET_VISIBLE(settings.main_window)){
 		gtk_widget_queue_draw(settings.main_window);
@@ -300,9 +309,15 @@ GtkWidget *get_menubar_menu( GtkWidget  *window, GtkItemFactoryEntry *menu_items
 void set_menu(){
 	//TODO: add stock icons
 	if (settings.enable_tray_menu){
-		GtkWidget *exit_entry = gtk_menu_item_new_with_mnemonic(_("_Exit"));
-		GtkWidget *config_entry = gtk_menu_item_new_with_mnemonic(_("_Config Window"));
-		GtkWidget *show_entry = gtk_menu_item_new_with_mnemonic(_("_Full Window"));
+		GtkWidget *exit_entry = gtk_image_menu_item_new_with_mnemonic(_("_Exit"));
+		GtkWidget *config_entry = gtk_image_menu_item_new_with_mnemonic(_("_Config Window"));
+		GtkWidget *show_entry = gtk_image_menu_item_new_with_mnemonic(_("_Full Window"));
+		GtkWidget *exit_icon = gtk_image_new_from_stock(GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU);
+		GtkWidget *config_icon = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+		GtkWidget *show_icon = gtk_image_new_from_stock(GTK_STOCK_PREFERENCES, GTK_ICON_SIZE_MENU);
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(exit_entry), exit_icon);
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(config_entry), config_icon);
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(show_entry), show_icon);
 		g_signal_connect(G_OBJECT(exit_entry), "activate", G_CALLBACK(gtk_main_quit), NULL);
 		g_signal_connect(G_OBJECT(config_entry), "activate", G_CALLBACK(configure), NULL);
 		g_signal_connect(G_OBJECT(show_entry), "activate", G_CALLBACK(open_window), NULL);
@@ -351,7 +366,7 @@ void set_menu(){
 }
 
 //save the position and dimensions of the window
-gboolean save_posdim(GtkWidget *widget, GdkEventConfigure *event, gpointer data){
+void save_posdim(GtkWidget *widget, GdkEventConfigure *event, gpointer data){
 	settings.window_x = event->x;
 	settings.window_y = event->y;
 	settings.window_width = event->width;
@@ -391,6 +406,11 @@ bool loop(int argc, char** argv) {
 	list_ptr = &list;
 	//reorder the controls to the order specified in the config file
 	settings.reorder_list(&list);
+
+	//set the scale
+	list.set_scale((Element::scale_t)settings.scaling);
+	//set the auto_mute
+	list.set_auto_mute(settings.auto_mute);
 	
 	//initialize gtk
 	gtk_init(&argc, &argv);
@@ -402,7 +422,11 @@ bool loop(int argc, char** argv) {
 		settings.tray_slider = new retro_slider;
 		settings.set_tray_slider(&list);
 		settings.apply_to_tray_slider(settings.tray_slider);
-		settings.tray_slider->init(tray_frame, (void*)settings.tray_control, &Element::get_callback, &Element::set_callback, (settings.tray_control->values > 1));
+		if (list.num_elems > 0){
+			settings.tray_slider->init(tray_frame, (void*)settings.tray_control, &Element::get_callback, &Element::set_callback, (settings.tray_control->values > 1));
+		} else {
+			settings.tray_control = NULL;
+		}
 
 		//set up the small window that holds the tray_slider
 		settings.slider_window = gtk_window_new (GTK_WINDOW_POPUP);
@@ -424,7 +448,7 @@ bool loop(int argc, char** argv) {
 		//set up tray icon
 #if GTK_CHECK_VERSION(2,16,0)
 		settings.tray_icon = gtk_status_icon_new();
-		gtk_status_icon_set_from_file(settings.tray_icon, VOL_MEDIUM_IMAGE);
+		gtk_status_icon_set_from_file(settings.tray_icon, VOL_MUTED_IMAGE);
 #else
 		settings.tray_icon = GTK_WIDGET(egg_tray_icon_new("Retrovol Tray Icon"));
 		//set the background color
@@ -456,7 +480,9 @@ bool loop(int argc, char** argv) {
 
 		//signals
 		g_signal_connect(G_OBJECT(settings.tray_icon), "button_press_event", G_CALLBACK (&tray_button_press_event_callback), settings.slider_window);
-		g_signal_connect(G_OBJECT(settings.tray_icon), "scroll_event", G_CALLBACK (&retro_slider::scroll_event_callback), settings.tray_slider);
+		if (settings.tray_control){
+			g_signal_connect(G_OBJECT(settings.tray_icon), "scroll_event", G_CALLBACK (&retro_slider::scroll_event_callback), settings.tray_slider);
+		}
 
 #if GTK_CHECK_VERSION(2,16,0)
 		//make icon visible
@@ -497,14 +523,14 @@ bool loop(int argc, char** argv) {
 	//define the menu
 	GtkItemFactoryEntry menu_items_1[] = {
 		{ (gchar*)_("/_File"),           NULL,              NULL,                      0, (gchar*)"<Branch>" },
-		{ (gchar*)_("/File/_Configure"), (gchar*)"<CTRL>C", G_CALLBACK(configure),     0, (gchar*)"<StockItem>", GTK_STOCK_NEW },
+		{ (gchar*)_("/File/_Configure"), (gchar*)"<CTRL>C", G_CALLBACK(configure),     0, (gchar*)"<StockItem>", GTK_STOCK_EXECUTE },
 		{ (gchar*)_("/File/_Quit"),      (gchar*)"<CTRL>Q", G_CALLBACK(close_window),  0, (gchar*)"<StockItem>", GTK_STOCK_QUIT },
 	};
 	gint nmenu_items_1 = sizeof (menu_items_1) / sizeof (menu_items_1[0]);
 	
 	GtkItemFactoryEntry menu_items_2[] = {
 		{ (gchar*)_("/_File"),           NULL,              NULL,                      0, (gchar*)"<Branch>" },
-		{ (gchar*)_("/File/_Configure"), (gchar*)"<CTRL>C", G_CALLBACK(configure),     0, (gchar*)"<StockItem>", GTK_STOCK_NEW },
+		{ (gchar*)_("/File/_Configure"), (gchar*)"<CTRL>C", G_CALLBACK(configure),     0, (gchar*)"<StockItem>", GTK_STOCK_EXECUTE },
 		{ (gchar*)_("/File/_Exit completely"),      (gchar*)"<CTRL>E", G_CALLBACK(gtk_main_quit),  0, (gchar*)"<StockItem>", GTK_STOCK_QUIT },
 		{ (gchar*)_("/File/_Quit"),      (gchar*)"<CTRL>Q", G_CALLBACK(close_window),  0, (gchar*)"<StockItem>", GTK_STOCK_QUIT },
 	};
@@ -663,14 +689,17 @@ bool loop(int argc, char** argv) {
 
 	//add some periodic refreshment to keep the icon and window up-to-date
 	#if GTK_CHECK_VERSION(2,14,0)
-		g_timeout_add_seconds(1, update, NULL);
+		int timeout = g_timeout_add_seconds(1, update, NULL);
 	#else
 		//this is less efficient than g_timeout_add_seconds()
-		g_timeout_add(1000, update, NULL);
+		int timeout = g_timeout_add(1000, update, NULL);
 	#endif
 	
 	//finished with gtk setup
 	gtk_main();
+
+	//stop the timeout
+	g_source_remove(timeout);
 	
 	//have the window shown again if it was open before we restarted
 	if (settings.resume_main){
